#include <miniball.hpp>
#include <cmath>
#ifndef NDEBUG
#include <cstdio>
#endif

#include "miniball_wrapper.h"

void miniball_wrapper(int n, int d, const double* const* x, double* c, double* r)
{
  #ifndef NDEBUG
  printf("DEBUG: Wrapper began.\n");
  #endif

  typedef const double* CoordIterator;
  typedef const double* const* PointIterator;
  typedef Miniball::Miniball <Miniball::CoordAccessor<PointIterator, CoordIterator> > Miniball;

  #ifndef NDEBUG
  printf("DEBUG: n=%d, d=%d, x=%p, c=%p, r=%p\n", n, d, x, c, r);
  for (int i = 0; i < n; i++)
  {
    printf("DEBUG: ");
    for (int j = 0; j < d; j++)
    {
      printf("%.20f ", x[i][j]);
    }
    printf("\n");
  }
  #endif

  Miniball mb(d, x, x+n);

  CoordIterator center = mb.center();
  
  #ifndef NDEBUG
  printf("DEBUG: Center: ");
  for (int i = 0; i < d; i++)
    printf("%.10f ", center[i]);
  printf("\n");
  #endif

  for (int i = 0; i < d; i++)
    c[i] = center[i];

  *r = sqrt(mb.squared_radius());
  
  #ifndef NDEBUG
  printf("DEBUG: Wrapper finished.\n");
  #endif
}
